clear all
load human_to_reduced_data/data_spatial_2.mat 

form_times = 0:0.01:4.5;
posts = zeros(length(counts), length(form_times)-1);
posts2 = zeros(length(counts), length(form_times)-1);
likelihoods = zeros(length(counts), length(form_times)-1);

for i = 1:length(counts)
   [posterior, tc] = age_posterior(counts(i),areas(i),max(form_times));
   [~,likelihood,~] = age_prior(counts(i),areas(i),max(form_times));
   likelihoods(i,:) = cumsum(likelihood)/sum(likelihood);
   posts(i,:) = 1 - cumsum(posterior');
   posts2(i,:) = posterior';
end

iseqlatfan = ((unitlats > -10) & (unitlats <= 10) & (hasfans == 1));
posts = posts(hasfans == 1,:);
fanunitlats = unitlats(hasfans == 1);
lowlats = posts(fanunitlats <= -10,:);
eqlats = posts((fanunitlats > -10) & (fanunitlats <= 10),:);
highlats = posts(abs(fanunitlats) > 10,:);
islowelev = mean_unit_fan_elev(hasfans ==1)<= -1500;
lowelevs = posts(islowelev==1,:);
ishighelev = mean_unit_fan_elev(hasfans ==1)> -1500;
highelevs = posts(ishighelev==1,:);

fig2 = figure('color',[1 1 1]);
semilogy(form_times(1:end-1),prod(lowlats,1),'linewidth',2,'Color',[0, 0.4470, 0.7410]);
hold on
semilogy(form_times(1:end-1),prod(eqlats,1),'linewidth',2,'Color',[0.8500, 0.3250, 0.0980]);
semilogy(form_times(1:end-1),prod(highlats,1),'linewidth',2,'Color',[0.9290, 0.6940, 0.1250]);
semilogy(form_times(1:end-1),...
    prod(lowlats(hasembed(fanunitlats <= -10) ==1 | hasclimatefans(fanunitlats <= -10) ==1,...
    :),1),'linewidth',2,'linestyle','--','Color',[0, 0.4470, 0.7410]);
semilogy(form_times(1:end-1), prod(eqlats(hasembed(iseqlatfan,:)==1 | hasclimatefans(iseqlatfan,:)==1 ,:),1),...
    'linewidth',2,'linestyle','--','Color',[0.8500, 0.3250, 0.0980]);
semilogy(form_times(1:end-1),...
    prod(highlats(hasembed(fanunitlats > 10) ==1 | hasclimatefans(fanunitlats > 10) ==1,...
    :),1),'linewidth',2,'linestyle','--','Color',[0.9290, 0.6940, 0.1250]);
plot([0 4],[0.05 0.05],'color','k','linestyle','--','linewidth',1);

axis([0 4 0.0001 1]);
legend('All Latitude < -10^o','Equatorial','All Latitude > 10^o','Low Lat. Local Impact excluded',...
    'Equatorial Local Impact Excluded','High Lat. Local Impact Excluded','location','southwest');
set(gca,'fontsize',10);
xlabel('Time, t_{ref} (Gyr)');
ylabel({'CDF of Youngest Fan Age','P(t_{min} \geq t_{ref} | t_{ref})'});
grid minor
fig2.PaperUnits = 'centimeters';
fig2.PaperPosition = [0 0 11 9.5];
print(fig2,'SPATIAL2','-dtiffn','-r500');

fig3 = figure('color',[1 1 1]);
semilogy(form_times(1:end-1),prod(lowelevs,1),'linewidth',2,'Color',[0, 0.4470, 0.7410]);
hold on
semilogy(form_times(1:end-1),prod(highelevs,1),'linewidth',2,'Color',[0.8500, 0.3250, 0.0980]);

embed2 = hasembed(hasfans == 1);
climate2 = hasclimatefans(hasfans == 1);
semilogy(form_times(1:end-1),...
    prod(lowelevs(embed2(islowelev==1) ==1 | climate2(islowelev) ==1,...
    :),1),'linewidth',2,'linestyle','--','Color',[0, 0.4470, 0.7410]);
semilogy(form_times(1:end-1),...
    prod(highelevs(embed2(ishighelev==1) ==1 | climate2(ishighelev) ==1,...
    :),1),'linewidth',2,'linestyle','--','Color',[0.8500, 0.3250, 0.0980]);
plot([0 4],[0.05 0.05],'color','k','linestyle','--','linewidth',1);

legend('All Elevation < -1500m','All Elevation > 1500m',...
    'Low Elev. Local Impact Excluded','High Elev. Local Impact Excluded',...
    'location','southwest');
    

grid minor
axis([0 4 0.0001 1]);
fig3.PaperUnits = 'centimeters';
fig3.PaperPosition = [0 0 11 9.5];
print(fig3,'SPATIAL3','-dtiffn','-r500');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [posterior, tc] = age_posterior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end

function [prior, likelihood,tc] = age_prior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end